@@ -106,8 +106,8 @@ class CodeRunner:
     def _cast(self, p: VariableState) -> Any:
         if p.param_type == "int":
             return int(p.param_value)
-        if p.param_value == "float":
-            return int(p.param_value)
+        if p.param_type == "float":
+            return float(p.param_value)
         if p.param_type == "list":
             return p.param_value
         return str(p.param_value)
