@@ -1,9 +1,22 @@
 from dataclasses import dataclass, field
-from typing import Any, Literal
+from typing import Literal
 
 PythonTaskResult = Literal["passed", "failed", "not_runned"]
 
 
+@dataclass
+class VariableState:
+    param_name: str
+    param_type: str
+    param_value: str
+
+
+@dataclass
+class TestCaseState:
+    inputs: list[VariableState]
+    expected: VariableState
+
+
 @dataclass
 class PythonTaskState:
     id: int
@@ -12,8 +25,8 @@ class PythonTaskState:
     code_template: str
     code: str
     quiz_id: str
-    test_cases: list[dict[str, Any]] = field(
-        default_factory=list[dict[str, Any]]
+    test_cases: list[TestCaseState] = field(
+        default_factory=list[TestCaseState]
     )
     is_passed: PythonTaskResult = "not_runned"
 
