@@ -3,6 +3,7 @@ from analyst_klondike.features.code.actions import RunAllCodeAction
 from analyst_klondike.features.data_context.init_action import InitAction
 from analyst_klondike.features.data_context.json_load.dc import get_quiz_json
 from analyst_klondike.features.data_context.set_opened_file_action import SetOpenedFileAction
+from analyst_klondike.features.events.event_hook import send_event
 from analyst_klondike.features.message_box.actions import HideMessageBoxAction
 from analyst_klondike.state.app_dispatch import app_dispatch
 
@@ -24,3 +25,4 @@ def start_demo_quiz():
     app_dispatch(InitAction(data=load_result))
     app_dispatch(RunAllCodeAction())
     app_dispatch(HideMessageBoxAction())
+    send_event("start_demo_quiz", "/")
