@@ -1,6 +1,7 @@
 from dataclasses import dataclass
 import httpx
 import analyst_klondike
+from analyst_klondike.features.events.event_hook import send_event
 from analyst_klondike.features.message_box.actions import DisplayMessageBoxAction
 from analyst_klondike.state.app_dispatch import app_dispatch
 
@@ -43,13 +44,14 @@ def close_app() -> None:
     # pylint: disable=import-outside-toplevel
     from analyst_klondike.ui.runner_app import get_app
     app = get_app()
+    send_event("app_closed_after_outdated", "/")
     app.exit(0)
 
 
 def display_message_if_outdated():
     res = _is_outdated()
     if res.is_outdated:
-        # update_package()
+        send_event("app_is_outdated", "/")
         app_dispatch(
             DisplayMessageBoxAction(
                 message=f"Доступна новая версия {res.latest_version} " +
