@@ -1,6 +1,6 @@
 from copy import deepcopy
 from dataclasses import dataclass
-from typing import Any, Callable
+from typing import Any, Callable, Literal
 from analyst_klondike.features.code.state import RunCodeState
 from analyst_klondike.features.current.current_state import CurrentState
 from analyst_klondike.features.data_context.data_state import DataState
@@ -21,6 +21,7 @@ class AppState:
     theme: str
     is_dark: bool
     is_editor_screen_ready: bool
+    event_sender: Literal["local_file", "local_db", "remote_db"]
     data: DataState
     current: CurrentState
     run_code: RunCodeState
@@ -36,7 +37,8 @@ INITIAL_STATE = AppState(
     current=CurrentState(),
     run_code=RunCodeState(),
     message_box=MessageBoxState(),
-    last_action_type=""
+    last_action_type="",
+    event_sender="remote_db"  # "local_file"
 )
 
 
